clusterdefaults

package
v0.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ApplyClusterDefaults

func ApplyClusterDefaults(
	config *deployer.Config,
) (*deployer.Config, error)

ApplyClusterDefaults detects the cluster type and applies appropriate defaults to the provided deployer.Config. Returns *just* the assembled defaults for the given cluster type for logging purposes.

func ResolveAutoResourceProfile

func ResolveAutoResourceProfile(clusterType types.ClusterType) types.ResourceProfile

ResolveAutoResourceProfile resolves the "auto" resource profile depending on the cluster type.

Types

This section is empty.

Jump to