imagecache

package
v0.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CacheData

type CacheData struct {
	Images []string `json:"images"`
}

CacheData represents the structure of the cache file

type ImageCache

type ImageCache struct {
	// contains filtered or unexported fields
}

ImageCache manages cache of verified pullable Docker images

func New

func New(log *logger.Logger, cacheFile string, maxEntries int) (*ImageCache, error)

New creates a new ImageCache instance

func (*ImageCache) AddToCache

func (ic *ImageCache) AddToCache(imageRef string)

AddToCache adds image to cache, maintaining max_entries limit

func (*ImageCache) IsCached

func (ic *ImageCache) IsCached(imageRef string) bool

IsCached checks if image is in cache

func (*ImageCache) VerifyImagePullable

func (ic *ImageCache) VerifyImagePullable(ctx context.Context, imageRef string) bool

VerifyImagePullable verifies if image is pullable using cache when possible

func (*ImageCache) VerifyImagesPullable

func (ic *ImageCache) VerifyImagesPullable(ctx context.Context, images ...string) bool

VerifyImagesPullable verifies that Docker images are pullable using cached results

Jump to