imagetag

package
v0.4.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MainTag

type MainTag string

MainTag is a StackRox image tag as provided by the user (e.g. "4.11.x-dirty", "4.11.1", "4.11.0-937-gf0da38f1a"). All version fields in the config store this form.

func (MainTag) String

func (t MainTag) String() string

func (MainTag) ToOperatorTag

func (t MainTag) ToOperatorTag() OperatorTag

ToOperatorTag converts a MainTag to an OperatorTag by removing "-dirty" and replacing ".x" with ".0". The conversion is idempotent.

type OperatorTag

type OperatorTag string

OperatorTag is a semver-compatible tag derived from a MainTag, suitable for operator bundle images, Konflux image references, and version comparisons.

func (OperatorTag) String

func (t OperatorTag) String() string

Jump to