logger

package
v0.4.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Logger

type Logger struct {
	// contains filtered or unexported fields
}

Logger provides timestamped logging functionality

func New

func New() *Logger

New creates a new Logger instance

func (*Logger) Dim

func (l *Logger) Dim(message string)

Dim prints a dimmed message

func (*Logger) Dimf

func (l *Logger) Dimf(format string, args ...interface{})

Dimf prints a formatted dimmed message

func (*Logger) Error

func (l *Logger) Error(message string)

Error prints an error message with red styling to stderr

func (*Logger) Errorf

func (l *Logger) Errorf(format string, args ...interface{})

Errorf prints a formatted error message with red styling to stderr

func (*Logger) Info

func (l *Logger) Info(message string)

Info prints an info message with magenta styling

func (*Logger) Infof

func (l *Logger) Infof(format string, args ...interface{})

Infof prints a formatted info message with magenta styling

func (*Logger) Success

func (l *Logger) Success(message string)

Success prints a success message with green styling

func (*Logger) Successf

func (l *Logger) Successf(format string, args ...interface{})

Successf prints a formatted success message with green styling

func (*Logger) Warning

func (l *Logger) Warning(message string)

Warning prints a warning message with yellow styling

func (*Logger) Warningf

func (l *Logger) Warningf(format string, args ...interface{})

Warning prints a formatted warning message with yellow styling

Jump to