manifest

package
v0.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateManifestSecretOnCluster

func CreateManifestSecretOnCluster(ctx context.Context, log *logger.Logger, m RoxieManifest) error

func DeleteManifestSecret

func DeleteManifestSecret(ctx context.Context, log *logger.Logger) error

func DeleteRoxieNamespace

func DeleteRoxieNamespace(ctx context.Context, log *logger.Logger) error

func ManifestToCentralDeploymentInfo

func ManifestToCentralDeploymentInfo(ctx context.Context, log *logger.Logger, tempDir string, m *RoxieManifest) (types.CentralDeploymentInfo, error)

Types

type RoxieManifest

type RoxieManifest struct {
	RoxieEnvironment types.RoxieEnvironment `yaml:"roxieEnvironment"`
	Config           deployer.Config        `yaml:"config"`
}

RoxieManifest represents the data stored in the roxie manifest secret. We include the whole deployer Config for reproducibility purposes.

func LoadManifestSecret

func LoadManifestSecret(ctx context.Context, log *logger.Logger) (*RoxieManifest, error)

Jump to