paths

package
v0.4.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CacheDir

func CacheDir() (string, error)

CacheDir returns the cache directory to be used by roxie. This directory might not yet exist, it is the responsibility of the caller to make sure this directory exists before writing to it.

func UserConfigPath

func UserConfigPath(validateUserConfig bool) (string, error)

func UserConfigPathString

func UserConfigPathString() string

Types

This section is empty.

Jump to