stackroxversions

package
v0.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	SupportsAdditionalPrinterColumnsConstraint = func() *semver.Constraints {
		constraint, err := semver.NewConstraint(">= 4.9.0")
		if err != nil {
			panic("invalid semver constraint")
		}
		return constraint
	}()
)

Functions

func LookupLatestReleaseTagsViaGitHub added in v0.4.3

func LookupLatestReleaseTagsViaGitHub(ctx context.Context, atMost int) ([]string, error)

LookupLatestReleaseTagsViaGitHub queries the GitHub releases API for stackrox/stackrox and attempts to return the newest atMost stable release tags (e.g. ["4.11.0", "4.10.4", "4.9.8"]), sorted by descending semver. Pre-release and RC tags are excluded. It is not guaranteed that the function returns exactly atMost tags, though this should be the case for reasonable values of atMost (0 < atMost < 10). The code is deliberately kept simple, i.e. it is not using pagination, which would smell like over-engineering for the use-case we need this for.

func SupportsAdditionalPrinterColumns

func SupportsAdditionalPrinterColumns(version string) (bool, error)

SupportsAdditionalPrinterColumns checks if the provided main image tag supports the additional printer columns (i.e., >= 4.9.0).

Types

This section is empty.

Jump to