types

package
v0.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ResourceProfiles

func ResourceProfiles() []string

func ResourceProfilesJoined

func ResourceProfilesJoined() string

Types

type CentralDeploymentInfo added in v0.4.1

type CentralDeploymentInfo struct {
	Endpoint       string
	Username       string
	Password       string
	KubeContext    string
	Exposure       Exposure
	CACertFile     string
	HAProxyStarted bool
}

CentralDeploymentInfo holds the state of a Central deployment.

type ClusterType

type ClusterType string

ClusterType represents different types of Kubernetes clusters

const (
	// ClusterTypeUnknown represents an unidentified cluster type
	ClusterTypeUnknown ClusterType = ""
	// ClusterTypeInfraGKE represents a GKE cluster created via Infra.
	ClusterTypeInfraGKE ClusterType = "InfraGKE"
	// ClusterTypeInfraOpenShift4 represents an OpenShift 4 cluster
	ClusterTypeInfraOpenShift4 ClusterType = "InfraOpenShift4"
	// Generic OpenShift4 cluster (e.g. for prow CI)
	ClusterTypeOpenShift4 ClusterType = "OpenShift4"
	// ClusterTypeKind represents a Kind (Kubernetes in Docker) cluster
	ClusterTypeKind ClusterType = "Kind"
	// ClusterTypeMinikube represents a Minikube cluster
	ClusterTypeMinikube ClusterType = "Minikube"
	// ClusterTypeK3s represents a K3s cluster
	ClusterTypeK3s ClusterType = "K3s"
	// ClusterTypeCRC represents a CRC (CodeReady Containers) cluster
	ClusterTypeCRC ClusterType = "CRC"
)

func AllClusterTypes

func AllClusterTypes() []ClusterType

func (ClusterType) IsLocal added in v0.4.2

func (ct ClusterType) IsLocal() bool

func (ClusterType) IsOpenShift

func (ct ClusterType) IsOpenShift() bool

func (ClusterType) NeedsPullSecrets added in v0.4.1

func (ct ClusterType) NeedsPullSecrets() bool

func (ClusterType) String

func (ct ClusterType) String() string

String returns the string representation of a ClusterType

func (*ClusterType) UnmarshalYAML added in v0.4.1

func (ct *ClusterType) UnmarshalYAML(unmarshal func(any) error) error

type Exposure

type Exposure int
const (
	ExposureNone Exposure = iota
	ExposureLoadBalancer
)

func (Exposure) MarshalYAML

func (e Exposure) MarshalYAML() (interface{}, error)

func (Exposure) String

func (e Exposure) String() string

func (*Exposure) ToUnstructuredConfig

func (e *Exposure) ToUnstructuredConfig() map[string]interface{}

ToUnstructuredConfig returns the exposure configuration.

func (*Exposure) UnmarshalYAML

func (e *Exposure) UnmarshalYAML(unmarshal func(interface{}) error) error

type ResourceProfile

type ResourceProfile int
const (
	ResourceProfileAcsDefaults ResourceProfile = iota
	ResourceProfileAuto
	ResourceProfileSmall
	ResourceProfileMedium
	ResourceProfileCI
)

func (ResourceProfile) MarshalYAML

func (r ResourceProfile) MarshalYAML() (interface{}, error)

func (ResourceProfile) String

func (r ResourceProfile) String() string

func (*ResourceProfile) UnmarshalYAML

func (r *ResourceProfile) UnmarshalYAML(unmarshal func(interface{}) error) error

type RoxieEnvironment added in v0.4.1

type RoxieEnvironment struct {
	APIEndpoint      string `yaml:"API_ENDPOINT,omitempty"`
	RoxAdminPassword string `yaml:"ROX_ADMIN_PASSWORD,omitempty"`
	RoxBaseURL       string `yaml:"ROX_BASE_URL,omitempty"`
	RoxEndpoint      string `yaml:"ROX_ENDPOINT,omitempty"`
	RoxUsername      string `yaml:"ROX_USERNAME,omitempty"`
	RoxCaCertFile    string `yaml:"ROX_CA_CERT_FILE,omitempty"`
}

RoxieEnvironment is the environment used during runtime. It includes another field, which shall not be stored on the cluster, since it is a local path.

func (RoxieEnvironment) Export added in v0.4.1

func (r RoxieEnvironment) Export() iter.Seq2[string, string]

Export() returns an iterator, which produces key,val pairs for the roxie environment. This includes local-only fields unlike YAML serialization, which only produces those values which shall actually be persisted.

func (RoxieEnvironment) MarshalYAML added in v0.4.1

func (r RoxieEnvironment) MarshalYAML() (any, error)

MarshalYAML skips local-only fields (ROX_CA_CERT_FILE).

Jump to