Documentation
¶
Index ¶
- func BuildDependencies(log *logger.Logger, chartPath string) error
- func Install(helmCtx HelmCtx, opts InstallOptions) error
- func ListByPrefix(helmCtx HelmCtx, prefix, namespace string) ([]string, error)
- func Uninstall(helmCtx HelmCtx, releaseName, namespace string) error
- type HelmCtx
- type InstallOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildDependencies ¶
BuildDependencies fetches missing sub-chart dependencies for a local chart directory. It is a no-op if the chart has no dependencies or all are already present.
func Install ¶
func Install(helmCtx HelmCtx, opts InstallOptions) error
Install installs or upgrades a Helm chart idempotently.
func ListByPrefix ¶
ListByPrefix returns the names of Helm releases whose name starts with the given prefix.
Types ¶
Click to show internal directories.
Click to hide internal directories.