Documentation
¶
Index ¶
- func DeepMerge(base, overlay map[string]interface{}) error
- func InsecureRandomString(n int) string
- func IsNil(i interface{}) bool
- func LoadYAMLFile(path string) (map[string]interface{}, error)
- func LogMultilineYaml(log *logger.Logger, v any) error
- func LookupLatestTag(ctx context.Context, log *logger.Logger) (string, error)
- func LookupMainImageTag(ctx context.Context, log *logger.Logger) (string, error)
- func MapToStruct(m map[string]interface{}, out interface{}) error
- func MergeMaps(base map[string]interface{}, overlays ...map[string]interface{}) (map[string]interface{}, error)
- func RunCommandWithOutput(title string, name string, args []string, opts ...CommandOption) (string, string, error)
- type CommandOption
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InsecureRandomString ¶ added in v0.4.6
func IsNil ¶
func IsNil(i interface{}) bool
IsNil uses reflection to reliably check if the provided argument is a Nil pointer.
func LoadYAMLFile ¶
LoadYAMLFile loads a YAML file and unmarshals it into a map Returns an empty map if path is empty or file doesn't exist
func LookupLatestTag ¶ added in v0.4.3
Computes the latest image tag for a pullable, released main image.
func LookupMainImageTag ¶
func MapToStruct ¶
func MergeMaps ¶
func MergeMaps(base map[string]interface{}, overlays ...map[string]interface{}) (map[string]interface{}, error)
MergeMaps deeply merges multiple maps, with later maps taking precedence
func RunCommandWithOutput ¶
func RunCommandWithOutput(title string, name string, args []string, opts ...CommandOption) (string, string, error)
RunCommandWithOutput executes a command and captures stdout/stderr
Types ¶
type CommandOption ¶
CommandOption is a function that modifies an exec.Cmd
Click to show internal directories.
Click to hide internal directories.