Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CacheData ¶
type CacheData struct {
Images []string `json:"images"`
}
CacheData represents the structure of the cache file
type ImageCache ¶
type ImageCache struct {
// contains filtered or unexported fields
}
ImageCache manages cache of verified pullable Docker images
func (*ImageCache) AddToCache ¶
func (ic *ImageCache) AddToCache(imageRef string)
AddToCache adds image to cache, maintaining max_entries limit
func (*ImageCache) IsCached ¶
func (ic *ImageCache) IsCached(imageRef string) bool
IsCached checks if image is in cache
func (*ImageCache) VerifyImagePullable ¶
func (ic *ImageCache) VerifyImagePullable(ctx context.Context, imageRef string) bool
VerifyImagePullable verifies if image is pullable using cache when possible
func (*ImageCache) VerifyImagesPullable ¶
func (ic *ImageCache) VerifyImagesPullable(ctx context.Context, images ...string) bool
VerifyImagesPullable verifies that Docker images are pullable using cached results
Click to show internal directories.
Click to hide internal directories.