Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CacheDir ¶
CacheDir returns the cache directory to be used by roxie. This directory might not yet exist, it is the responsibility of the caller to make sure this directory exists before writing to it.
func UserConfigPath ¶
func UserConfigPathString ¶
func UserConfigPathString() string
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.